/*
 * Copyright (C) 2010 David Arkell.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.gwtorbit.client.mvp;

import java.util.ArrayList;

import com.google.gwt.event.logical.shared.ValueChangeEvent;
import com.google.gwt.event.logical.shared.ValueChangeHandler;
import com.google.gwt.event.shared.HandlerManager;
import com.google.gwt.user.client.History;

public class AppEventBus implements ValueChangeHandler<String>, PlaceChangedEventHandler {

	private static AppEventBus instance;

	private HandlerManager eventBus;

	private ArrayList<AppController> appControllers = new ArrayList<AppController>();

	public static AppEventBus getInstance() {
		if (instance == null) {
			instance = new AppEventBus();
		}
		return instance;
	}

	private AppEventBus() {
		History.addValueChangeHandler(this);
		eventBus = new HandlerManager(null);
		eventBus.addHandler(PlaceChangedEvent.TYPE, this);
	}

	public void onValueChange(ValueChangeEvent<String> event) {
		String token = event.getValue();
		eventBus.fireEvent(new PlaceChangedEvent(token));
	}

	public void onPlaceChanged(PlaceChangedEvent event) {
		String place = event.getPlace();

		for (AppController appController : appControllers) {
			appController.setPlace(place);
		}
	}

	public HandlerManager getEventBus() {
		return eventBus;
	}

	public void addAppController(AppController appController) {
		appControllers.add(appController);
	}

	public void setPlace(String place) {
		History.newItem(place, false);
		History.fireCurrentHistoryState();
	}
}
