/*
 * Copyright (C) 2010 David Arkell.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.gwtorbit.client.widgets;

import com.google.gwt.user.client.ui.HorizontalPanel;
import com.google.gwt.user.client.ui.SimplePanel;
import com.google.gwt.user.client.ui.Widget;
import com.gwtorbit.client.model.UiErrorDisplay;
import com.gwtorbit.client.model.UiErrors;

public abstract class FormAbstractRowWithUiErrorDisplay extends HorizontalPanel implements
		UiErrorDisplay {

	private SimplePanel leftPanel;

	private LLabel label;

	private SimplePanel outerFieldPanel;

	private UiErrorDisplayVP errorsDisplay;

	private HorizontalPanel fieldHorizontalPanel;

	private SimplePanel fieldPrefix;

	private LHTML fieldPrefixHtml;

	private SimplePanel innerFieldPanel;

	private SimplePanel fieldSuffix;

	private LHTML fieldSuffixHtml;

	public FormAbstractRowWithUiErrorDisplay() {
		setStyleName("UiFormRow");

		leftPanel = new SimplePanel();
		leftPanel.setStyleName("UiFormFieldLeft");
		super.add(leftPanel);

		label = new LLabel();
		label.setStyleName("UiFormFieldLabel");
		super.add(label);

		outerFieldPanel = new SimplePanel();
		outerFieldPanel.setStyleName("UiFormFieldOuter");
		super.add(outerFieldPanel);

		fieldHorizontalPanel = new HorizontalPanel();
		outerFieldPanel.setWidget(fieldHorizontalPanel);

		fieldPrefix = new SimplePanel();
		fieldHorizontalPanel.add(fieldPrefix);

		innerFieldPanel = new SimplePanel();
		fieldHorizontalPanel.add(innerFieldPanel);

		fieldSuffix = new SimplePanel();
		fieldHorizontalPanel.add(fieldSuffix);

		errorsDisplay = new UiErrorDisplayVP();
		super.add(errorsDisplay);
	}

	protected void setFieldPrefix(Widget w) {
		fieldPrefix.setWidget(w);
	}

	protected Widget getFieldPrefix() {
		return fieldPrefix.getWidget();
	}

	protected void setFieldSuffix(Widget w) {
		fieldSuffix.setWidget(w);
	}

	protected Widget getFieldSuffix() {
		return fieldSuffix.getWidget();
	}

	private void createFieldSuffixHtml() {
		if (fieldSuffixHtml == null) {
			fieldSuffixHtml = new LHTML();
			fieldSuffix.setWidget(fieldSuffixHtml);
			fieldSuffix.setStyleName("UiFormFieldSuffix");
		}
	}

	private void createFieldPrefixHtml() {
		if (fieldPrefixHtml == null) {
			fieldPrefixHtml = new LHTML();
			fieldPrefix.setWidget(fieldPrefixHtml);
			fieldPrefix.setStyleName("UiFormFieldPrefix");
		}
	}

	public void setFieldSuffixTextKey(String key) {
		createFieldSuffixHtml();
		fieldSuffixHtml.setTextKey(key);
	}

	public void setFieldSuffixText(String text) {
		createFieldSuffixHtml();
		fieldSuffixHtml.setText(text);
	}

	public void setFieldSuffixHtmlKey(String key) {
		createFieldSuffixHtml();
		fieldSuffixHtml.setKey(key);
	}

	public void setFieldSuffixHtml(String html) {
		createFieldSuffixHtml();
		fieldSuffixHtml.setHTML(html);
	}

	public void setFieldPrefixTextKey(String key) {
		createFieldPrefixHtml();
		fieldPrefixHtml.setTextKey(key);
	}

	public void setFieldPrefixText(String text) {
		createFieldPrefixHtml();
		fieldPrefixHtml.setText(text);
	}

	public void setFieldPrefixHtmlKey(String key) {
		createFieldPrefixHtml();
		fieldPrefixHtml.setKey(key);
	}

	public void setFieldPrefixHtml(String html) {
		createFieldPrefixHtml();
		fieldPrefixHtml.setHTML(html);
	}

	protected void setFieldWidget(Widget w) {
		innerFieldPanel.setWidget(w);
	}

	protected Widget getFieldWidget() {
		return innerFieldPanel.getWidget();
	}

	public void setLabelText(String labelText) {
		label.setText(labelText);
	}

	public void setLabelKey(String labelKey) {
		label.setKey(labelKey);
	}

	public void setMandatory(boolean mandatory) {
		this.mandatory = mandatory;
		if (mandatory) {
			label.addStyleName("UiFormFieldLabelMand");
		} else {
			label.removeStyleName("UiFormFieldLabelMand");
		}
	}

	public boolean isMandatory() {
		return mandatory;
	}

	private boolean mandatory;

	public String getDataName() {
		return errorsDisplay.getDataName();
	}

	public void setDataName(String dataName) {
		errorsDisplay.setDataName(dataName);
	}

	public void displayErrors(UiErrors errors, String errorPrefix) {
		errorsDisplay.displayErrors(errors, errorPrefix);
	}

	public void clearErrors() {
		errorsDisplay.clearErrors();
	}

	public LLabel getFormLabel() {
		return label;
	}

	public SimplePanel getLeftPanel() {
		return leftPanel;
	}
}
