/*
 * Copyright (C) 2010 David Arkell.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.gwtorbit.client.widgets;

import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.event.dom.client.ClickHandler;
import com.google.gwt.event.shared.HandlerRegistration;
import com.google.gwt.user.client.ui.HasText;
import com.google.gwt.user.client.ui.Label;
import com.gwtorbit.client.mvp.AppEventBus;
import com.gwtorbit.client.mvp.ClientResourceBundle;

public class LLink extends BFocusPanel implements HasText {

	private Label label;

	public LLink() {
		label = new Label("");
		this.setWidget(label);
		this.setStyleName("LLink");
	}

	public LLink(String key) {
		this();
		setKey(key);
	}

	public LLink(String key, String place) {
		this(key);
		setPlace(place);
	}

	public void setKey(String key) {
		label.setText(ClientResourceBundle.getString(key));
	}

	public String getText() {
		return label.getText();
	}

	public void setText(String text) {
		label.setText(text);
	}

	public void setHighlighted(boolean highlighted) {
		this.highlighted = highlighted;
		updateStyle();
	}

	public boolean isHighlighted() {
		return highlighted;
	}

	HandlerRegistration handlerRegistration = null;

	public void setPlace(String place) {
		this.place = place;

		if (handlerRegistration == null) {
			handlerRegistration = this.addClickHandler(new ClickHandler() {
				public void onClick(ClickEvent event) {
					AppEventBus.getInstance().setPlace(LLink.this.place);
				}
			});
		}
	}

	public String getPlace() {
		return place;
	}

	public void setEnabled(boolean enabled) {
		this.enabled = enabled;
		updateStyle();
	}

	private void updateStyle() {
		if (this.enabled) {
			if (this.highlighted) {
				this.setStyleName("LLinkHighlighted");
			} else {
				this.setStyleName("LLink");
			}
		} else {
			this.setStyleName("LLinkDisabled");
		}
	}

	public boolean isEnabled() {
		return enabled;
	}

	private boolean highlighted = false;

	private String place;

	private boolean enabled = true;

}
