/*
 * Copyright (C) 2010 David Arkell.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.gwtorbit.client.widgets;

import com.google.gwt.user.client.ui.CheckBox;
import com.gwtorbit.client.model.UiData;
import com.gwtorbit.client.model.UiDataDisplay;
import com.gwtorbit.client.model.UiErrorDisplay;
import com.gwtorbit.client.model.UiErrors;

public class UiCheckBox extends CheckBox implements UiDataDisplay, UiErrorDisplay {

	public void displayData(UiData uiData) {
		Boolean isChecked = (Boolean) uiData.getData(dataName);
		if (isChecked == null) {
			isChecked = false;
		}
		setValue(isChecked);
	}

	public void getData(UiData uiData, UiErrors errors, String errorPrefix) {
		Boolean checked = this.getValue();
		uiData.setData(dataName, checked);
	}

	private String dataName;

	public String getDataName() {
		return dataName;
	}

	public void setDataName(String dataName) {
		this.dataName = dataName;
	}

	public void clearErrors() {
		this.removeStyleName("UiTextBoxError");
	}

	public void displayErrors(UiErrors errors, String errorPrefix) {
		if (errors.hasErrors(errorPrefix + dataName)) {
			this.addStyleName("UiTextBoxError");
		}
	}

	public void clearData() {
		setValue(false);
	}

	private boolean ignore = false;

	public boolean getIgnore() {
		return ignore;
	}

	public void setIgnore(boolean ignore) {
		this.ignore = ignore;
	}

}
