/*
 * Copyright (C) 2010 David Arkell.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.gwtorbit.client.widgets;

import java.util.ArrayList;

import com.google.gwt.user.client.ui.Label;
import com.google.gwt.user.client.ui.VerticalPanel;
import com.gwtorbit.client.model.UiError;
import com.gwtorbit.client.model.UiErrorDisplay;
import com.gwtorbit.client.model.UiErrors;
import com.gwtorbit.client.model.UiLocalizedError;
import com.gwtorbit.client.model.UiSimpleError;
import com.gwtorbit.client.mvp.ClientResourceBundle;

public class UiErrorDisplayVP extends VerticalPanel implements UiErrorDisplay {

	public UiErrorDisplayVP() {
		this.setStyleName("UiErrorDisplayVP");
	}

	public void clearErrors() {
		this.clear();
	}

	public void displayErrors(UiErrors errors, String errorPrefix) {
		if (errors.hasErrors(errorPrefix + dataName)) {
			ArrayList<UiError> errorList = errors.getErrors(errorPrefix + dataName);
			for (UiError error : errorList) {
				if (error instanceof UiSimpleError) {
					UiSimpleError simpleError = (UiSimpleError) error;
					Label label = new Label(simpleError.getErrorString());
					label.setStyleName("UiErrorDisplayVPLabel");
					this.add(label);
				} else if (error instanceof UiLocalizedError) {
					UiLocalizedError localizedError = (UiLocalizedError) error;
					Label label = new Label(ClientResourceBundle.getString(localizedError.getKey()));
					label.setStyleName("UiErrorDisplayVPLabel");
					this.add(label);
				}
			}
		}
	}

	private String dataName;

	public String getDataName() {
		return dataName;
	}

	public void setDataName(String dataName) {
		this.dataName = dataName;
	}

}
