/*
 * Copyright (C) 2010 David Arkell.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.gwtorbit.client.widgets;

import java.util.ArrayList;
import java.util.Iterator;

import com.google.gwt.user.client.ui.HasWidgets;
import com.google.gwt.user.client.ui.ListBox;
import com.google.gwt.user.client.ui.Widget;
import com.gwtorbit.client.model.UiData;
import com.gwtorbit.client.model.UiDataDisplay;
import com.gwtorbit.client.model.UiErrorDisplay;
import com.gwtorbit.client.model.UiErrors;
import com.gwtorbit.client.model.UiLocalizedError;
import com.gwtorbit.client.mvp.ClientResourceBundle;

public class UiListBox extends ListBox implements HasWidgets, UiDataDisplay, UiErrorDisplay {

	private ArrayList<Object> optionsData = new ArrayList<Object>();

	public void displayData(UiData uiData) {
		Object data = uiData.getData(dataName);
		for (int i = 0; i < optionsData.size(); i++) {
			if (optionsData.get(i).equals(data)) {
				this.setSelectedIndex(i);
				break;
			}
		}
	}

	public Object getData() {
		int index = getSelectedIndex();
		if (index == -1) {
			return null;
		}

		return optionsData.get(index);
	}

	public void getData(UiData uiData, UiErrors errors, String errorPrefix) {
		Object data = getData();

		if (mandatory && (data == null || "".equals(data))) {
			errors.addError(errorPrefix + dataName, UiLocalizedError.MANDATORY);
		}

		uiData.setData(dataName, data);
	}

	private boolean mandatory = false;

	private String dataName;

	public String getDataName() {
		return dataName;
	}

	public void setDataName(String dataName) {
		this.dataName = dataName;
	}

	public void setMandatory(boolean mandatory) {
		this.mandatory = mandatory;
	}

	public boolean isMandatory() {
		return mandatory;
	}

	public void clearErrors() {
		this.removeStyleName("UiTextBoxError");
	}

	public void displayErrors(UiErrors errors, String errorPrefix) {
		if (errors.hasErrors(errorPrefix + dataName)) {
			this.addStyleName("UiTextBoxError");
		}
	}

	public void clearData() {
		this.setSelectedIndex(0);
	}

	private boolean ignore = false;

	public boolean getIgnore() {
		return ignore;
	}

	public void setIgnore(boolean ignore) {
		this.ignore = ignore;
	}

	public void addItem(String item) {
		addItem(item, item);
	}

	public void addItem(String item, String value) {
		addOption(item, value);
	}

	public void addOption(String label, Object value) {
		optionsData.add(value);
		super.addItem(label);
	}

	public void add(Widget w) {
		if (w instanceof UiOption) {
			UiOption uiOption = (UiOption) w;

			String label = uiOption.getLabel();
			if (uiOption.getLabelKey() != null) {
				label = ClientResourceBundle.getString(uiOption.getLabelKey());
			}
			this.addOption(label, uiOption.getValue());
		}
	}

	public Iterator<Widget> iterator() {
		return new Iterator<Widget>() {
			public boolean hasNext() {
				return false;
			}

			public Widget next() {
				return null;
			}

			public void remove() {
			}
		};
	}

	public boolean remove(Widget w) {
		return false;
	}

	private String fieldSize;

	public void setFieldSize(String size) {
		if ("short".equalsIgnoreCase(size)) {
			fieldSize = "short";
			setStyleName("UiListBoxShort");
		} else if ("long".equalsIgnoreCase(size)) {
			fieldSize = "long";
			setStyleName("UiListBoxLong");
		} else {
			fieldSize = "medium";
			setStyleName("UiListBoxMedium");
		}
	}

	public String getFieldSize() {
		return fieldSize;
	}

}
