/*
 * Copyright (C) 2010 David Arkell.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.gwtorbit.client.widgets;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashSet;

import com.google.gwt.user.client.ui.CheckBox;
import com.google.gwt.user.client.ui.VerticalPanel;
import com.google.gwt.user.client.ui.Widget;
import com.gwtorbit.client.model.UiData;
import com.gwtorbit.client.model.UiDataDisplay;
import com.gwtorbit.client.model.UiErrorDisplay;
import com.gwtorbit.client.model.UiErrors;
import com.gwtorbit.client.model.UiLocalizedError;
import com.gwtorbit.client.mvp.ClientResourceBundle;

public class UiListOfCheckBoxes extends VerticalPanel implements UiDataDisplay, UiErrorDisplay {

	private ArrayList<Object> optionsData = new ArrayList<Object>();

	@SuppressWarnings("unchecked")
	public void displayData(UiData uiData) {
		this.clearData();
		if ("string".equals(dataType)) {
			String data = (String) uiData.getData(dataName);
			if (data != null) {
				HashSet<String> hs = new HashSet<String>(Arrays.asList(data.split(stringSeparator)));
				for (int i = 0; i < optionsData.size(); i++) {
					if (hs.contains(optionsData.get(i))) {
						CheckBox cb = (CheckBox) this.getWidget(i);
						cb.setValue(true);
					}
				}
			}
		} else if ("list".equals(dataType)) {
			ArrayList data = (ArrayList) uiData.getData(dataName);

			for (int i = 0; i < data.size(); i++) {
				for (int j = 0; j < optionsData.size(); j++) {
					if (data.get(i).equals(optionsData.get(j))) {
						CheckBox cb = (CheckBox) this.getWidget(j);
						cb.setValue(true);
					}
				}
			}
		}
	}

	public void getData(UiData uiData, UiErrors errors, String errorPrefix) {
		if ("string".equals(dataType)) {
			String data = null;
			for (int i = 0; i < optionsData.size(); i++) {
				CheckBox cb = (CheckBox) this.getWidget(i);
				if (cb.getValue()) {
					if (data == null) {
						data = optionsData.get(i).toString();
					} else {
						data += stringSeparator + optionsData.get(i).toString();
					}
				}
			}

			if (mandatory && data == null) {
				errors.addError(errorPrefix + dataName, UiLocalizedError.MANDATORY);
			}
			uiData.setData(dataName, data);
		} else if ("list".equals(dataType)) {
			ArrayList<Object> data = new ArrayList<Object>();
			for (int i = 0; i < optionsData.size(); i++) {
				CheckBox cb = (CheckBox) this.getWidget(i);
				if (cb.getValue()) {
					data.add(optionsData.get(i));
				}
			}
			if (mandatory && data.size() == 0) {
				errors.addError(errorPrefix + dataName, UiLocalizedError.MANDATORY);
			}
			uiData.setData(dataName, data);
		}
	}

	private boolean mandatory = false;

	private String dataName;

	public String getDataName() {
		return dataName;
	}

	public void setDataName(String dataName) {
		this.dataName = dataName;
	}

	public void setMandatory(boolean mandatory) {
		this.mandatory = mandatory;
	}

	public boolean isMandatory() {
		return mandatory;
	}

	public void clearErrors() {
		this.removeStyleName("UiTextBoxError");
	}

	public void displayErrors(UiErrors errors, String errorPrefix) {
		if (errors.hasErrors(errorPrefix + dataName)) {
			this.addStyleName("UiTextBoxError");
		}
	}

	public void clearData() {
		for (int i = 0; i < getWidgetCount(); i++) {
			CheckBox checkBox = (CheckBox) this.getWidget(i);
			checkBox.setValue(false);
		}
	}

	public void add(Widget w) {
		if (w instanceof UiOption) {
			UiOption uiOption = (UiOption) w;

			String label = uiOption.getLabel();
			if (uiOption.getLabelKey() != null) {
				label = ClientResourceBundle.getString(uiOption.getLabelKey());
			}
			this.addOption(label, uiOption.getValue());
		}
	}

	public void addOption(String label, Object value) {
		optionsData.add(value);
		CheckBox cb = new CheckBox(label);
		super.add(cb);
	}

	private boolean ignore = false;

	public boolean getIgnore() {
		return ignore;
	}

	public void setIgnore(boolean ignore) {
		this.ignore = ignore;
	}

	private String stringSeparator = ",";

	// string or list
	private String dataType = "string";

	public void setDataType(String dataType) {
		this.dataType = dataType;
	}

	public String getDataType() {
		return dataType;
	}

	public void setStringSeparator(String stringSeparator) {
		this.stringSeparator = stringSeparator;
	}

	public String getStringSeparator() {
		return stringSeparator;
	}

	public void clear() {
		optionsData.clear();
		super.clear();
	}

	public void clearOptions() {
		clear();
	}

}
